@@ -25,7 +25,7 @@ __version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"
 import os
 import pickle
 
-version = "0.9"
+version = "0.9.1"
 
 try:
     from glib import get_user_config_dir
@@ -218,23 +218,25 @@ class Config:
 	    ret=pickle.loads(st)
 
 	    if ret==None:
+		print "failed to load config"
 		ret=None
 	    else:
 		if ret['version']==1:
-		    ret=parse_v1(ret)
+		    ret=self.parse_v1(ret)
 
 		if ret['version']==2:
-		    ret=parse_v2(ret)
+		    ret=self.parse_v2(ret)
 
 		if ret['version']==3:
-		    ret=parse_v3(ret)
+		    ret=self.parse_v3(ret)
 
 		if ret['version']==4:
-		    ret=parse_v4(ret)
+		    ret=self.parse_v4(ret)
 
 		if ret['version']==5:
-		    ret=parse_v5(ret)
-	except:
+		    ret=self.parse_v5(ret)
+	except Exception, e:
+	    print "config error:", e
 	    ret=None
 
 	return(ret)
