@@ -22,6 +22,7 @@
 
 __version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"
 
+import os.path
 from drlaunch import widget
 
 class DrlaunchPlugin(widget.DrlaunchPlugin):
@@ -39,6 +40,9 @@ def redirect_err():
 
 hd_plugin_type = DrlaunchPlugin
 
+if os.path.exists('/tmp/drlaunch.log'):
+    redirect_err()
+
 if __name__=="__main__":
     import gobject
     import gtk
