@@ -129,6 +129,10 @@ class DrlaunchPlugin(IconGrid, HomePluginItem, FremantleRotation):
 	HomePluginItem.do_realize(self)
 
     def on_orientation_changed(self, orientation):
+	# Avoid bugs
+	if orientation==None or len(orientation)==0:
+	    return
+
 	# Get the first character of the string (l/p)
 	o=orientation[0]
 	self.setMode(o)
@@ -161,6 +165,8 @@ class DrlaunchPlugin(IconGrid, HomePluginItem, FremantleRotation):
 	config.setIndiv(dt['indiv'])
 	config.setLongpress(dt['longpress'])
 	config.setAnimate(dt['animate'])
+	config.setNoBg(dt['nobg'])
+	config.setThemeBg(dt['themebg'])
 	config.save()
 	
 	# Resize widget
@@ -176,6 +182,7 @@ class DrlaunchPlugin(IconGrid, HomePluginItem, FremantleRotation):
     def handle_click(self, sender, icon):
 	""" common handler for longpress and click """
 	if icon.name!=None and icon.name!='':
+	    print "name:", icon.name
 	    launcher.launch(icon.name)
 
     def signalLongpress(self, sender, icon):
